@@ -4,10 +4,12 @@ use serde::{
 };
 use std::collections::HashSet;
 
+use strum_macros::{Display, EnumString};
+
 /// Capabilities is a unique set of Capability values.
 pub type Capabilities = HashSet<Capability>;
 
-#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, Serialize)]
+#[derive(Clone, Copy, Debug, EnumString, Eq, Display, Hash, PartialEq, Serialize)]
 /// All available capabilities.
 ///
 /// For the purpose of performing permission checks, traditional UNIX
@@ -21,6 +23,7 @@ pub type Capabilities = HashSet<Capability>;
 /// Starting with kernel 2.2, Linux divides the privileges traditionally
 /// associated with superuser into distinct units, known as capabilities, which
 /// can be independently enabled and disabled. Capabilities are a per-thread attribute.
+#[strum(serialize_all = "SCREAMING_SNAKE_CASE")]
 pub enum Capability {
     #[serde(rename = "CAP_AUDIT_CONTROL")]
     /// Enable and disable kernel auditing; change auditing filter rules;
@@ -523,8 +526,20 @@ impl<'de> Deserialize<'de> for Capability {
     {
         let input = String::deserialize(deserializer)?;
         let upper = input.to_uppercase();
-        let stripped = upper.strip_prefix("CAP_").unwrap_or(&upper);
-        match stripped {
+
+        // Extract the capability name from various input formats.
+        //
+        // This function strips all "CAP_" prefixes to normalize capability names.
+        // This ensures correct adaptation regardless of whether users specify
+        // CAP_XXX or XXX directly at the upper layer(Specially k8s), making the
+        // API more flexible and user-friendly.
+        // Examples: "CAP_SYS_ADMIN", "SYS_ADMIN"
+        //
+        let mut clean_cap = upper.as_str();
+        while let Some(stripped) = clean_cap.strip_prefix("CAP_") {
+            clean_cap = stripped;
+        }
+        match clean_cap {
             "AUDIT_CONTROL" => Ok(Self::AuditControl),
             "AUDIT_READ" => Ok(Self::AuditRead),
             "AUDIT_WRITE" => Ok(Self::AuditWrite),
@@ -567,8 +582,7 @@ impl<'de> Deserialize<'de> for Capability {
             "SYSLOG" => Ok(Self::Syslog),
             "WAKE_ALARM" => Ok(Self::WakeAlarm),
             other => Err(Error::custom(format!(
-                "no variant for {} (converted to {})",
-                input, other,
+                "no variant for {input} (converted to {other})",
             ))),
         }
     }
@@ -588,8 +602,8 @@ mod tests {
 
     #[test]
     fn deserialize() -> Result<()> {
-        for case in vec!["SYSLOG", "CAP_SYSLOG", "cap_SYSLOG", "sySloG"] {
-            let res: Capability = serde_json::from_str(&format!("\"{}\"", case))?;
+        for case in &["SYSLOG", "CAP_SYSLOG", "cap_SYSLOG", "sySloG"] {
+            let res: Capability = serde_json::from_str(&format!("\"{case}\""))?;
             assert_eq!(Capability::Syslog, res);
         }
         Ok(())
@@ -610,4 +624,69 @@ mod tests {
         assert!(res.contains(&Capability::Chown));
         Ok(())
     }
+
+    #[test]
+    fn invalid_string2enum() {
+        let invalid_cap_str = "INVALID_CAP";
+        let unknown_cap = invalid_cap_str.parse::<Capability>();
+        assert!(unknown_cap.is_err());
+    }
+
+    #[test]
+    fn cap_enum_to_string() {
+        let cap = Capability::AuditControl;
+        assert_eq!(cap.to_string(), "AUDIT_CONTROL");
+
+        let cap = Capability::AuditRead;
+        assert_eq!(cap.to_string(), "AUDIT_READ");
+
+        let cap = Capability::SysAdmin;
+        assert_eq!(cap.to_string(), "SYS_ADMIN");
+    }
+
+    #[test]
+    fn cap_string_to_enum() {
+        let cap_str = "AUDIT_CONTROL";
+        let cap_enum: Capability = cap_str.parse().unwrap();
+        assert_eq!(cap_enum, Capability::AuditControl);
+
+        let cap_str = "AUDIT_READ";
+        let cap_enum: Capability = cap_str.parse().unwrap();
+        assert_eq!(cap_enum, Capability::AuditRead);
+
+        let cap_str = "SYS_ADMIN";
+        let cap_enum: Capability = cap_str.parse().unwrap();
+        assert_eq!(cap_enum, Capability::SysAdmin);
+    }
+
+    #[test]
+    fn test_serde_serialization() {
+        let cap = Capability::AuditControl;
+        let serialized = serde_json::to_string(&cap).unwrap();
+        assert_eq!(serialized, "\"CAP_AUDIT_CONTROL\"");
+
+        let cap = Capability::SysAdmin;
+        let serialized = serde_json::to_string(&cap).unwrap();
+        assert_eq!(serialized, "\"CAP_SYS_ADMIN\"");
+    }
+
+    #[test]
+    fn test_serde_deserialization() {
+        let serialized = "\"CAP_AUDIT_CONTROL\"";
+        let cap: Capability = serde_json::from_str(serialized).unwrap();
+        assert_eq!(cap, Capability::AuditControl);
+
+        let serialized = "\"CAP_SYS_ADMIN\"";
+        let cap: Capability = serde_json::from_str(serialized).unwrap();
+        assert_eq!(cap, Capability::SysAdmin);
+    }
+
+    #[test]
+    fn deserialize_one_more_cap_prefix() -> Result<()> {
+        for case in &["SYS_ADMIN", "CAP_CAP_SYS_ADMIN", "cap_CAP_cap_SYS_ADMIN"] {
+            let res: Capability = serde_json::from_str(&format!("\"{case}\""))?;
+            assert_eq!(Capability::SysAdmin, res);
+        }
+        Ok(())
+    }
 }
