@@ -1,10 +1,12 @@
 use crate::error::OciSpecError;
 use derive_builder::Builder;
-use getset::{CopyGetters, Getters};
+use getset::{CopyGetters, Getters, MutGetters, Setters};
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 
-#[derive(Builder, Clone, CopyGetters, Debug, Deserialize, Eq, Getters, PartialEq, Serialize)]
+#[derive(
+    Builder, Clone, CopyGetters, Debug, Deserialize, Eq, Getters, Setters, PartialEq, Serialize,
+)]
 #[builder(
     default,
     pattern = "owned",
@@ -16,13 +18,13 @@ use std::path::PathBuf;
 pub struct Root {
     /// Path is the absolute path to the container's root filesystem.
     #[serde(default)]
-    #[getset(get = "pub")]
+    #[getset(get = "pub", set = "pub")]
     path: PathBuf,
 
     /// Readonly makes the root filesystem for the container readonly before
     /// the process is executed.
     #[serde(default, skip_serializing_if = "Option::is_none")]
-    #[getset(get_copy = "pub")]
+    #[getset(get_copy = "pub", set = "pub")]
     readonly: Option<bool>,
 }
 
@@ -37,14 +39,26 @@ impl Default for Root {
     }
 }
 
-#[derive(Builder, Clone, Debug, Default, Deserialize, Eq, Getters, PartialEq, Serialize)]
+#[derive(
+    Builder,
+    Clone,
+    Debug,
+    Default,
+    Deserialize,
+    Eq,
+    Getters,
+    MutGetters,
+    Setters,
+    PartialEq,
+    Serialize,
+)]
 #[builder(
     default,
     pattern = "owned",
     setter(into, strip_option),
     build_fn(error = "OciSpecError")
 )]
-#[getset(get = "pub")]
+#[getset(get_mut = "pub", get = "pub", set = "pub")]
 /// Mount specifies a mount for a container.
 pub struct Mount {
     /// Destination is the absolute path where the mount will be placed in
@@ -145,3 +159,33 @@ pub fn get_default_mounts() -> Vec<Mount> {
         },
     ]
 }
+
+/// utility function to generate default rootless config for mounts.
+// TODO(saschagrunert): remove once clippy does not report this false positive any more. We cannot
+// use `inspect` instead of `map` because we need to mutate the mounts.
+// Ref: https://github.com/rust-lang/rust-clippy/issues/13185
+#[allow(clippy::manual_inspect)]
+pub fn get_rootless_mounts() -> Vec<Mount> {
+    let mut mounts = get_default_mounts();
+    mounts
+        .iter_mut()
+        .find(|m| m.destination.to_string_lossy() == "/dev/pts")
+        .map(|m| {
+            if let Some(opts) = &mut m.options {
+                opts.retain(|o| o != "gid=5")
+            }
+            m
+        });
+    mounts
+        .iter_mut()
+        .find(|m| m.destination.to_string_lossy() == "/sys")
+        .map(|m| {
+            m.typ = Some("none".to_string());
+            m.source = Some("/sys".into());
+            if let Some(o) = m.options.as_mut() {
+                o.push("rbind".to_string())
+            }
+            m
+        });
+    mounts
+}
